# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: profi_optim_lite.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='profi_optim_lite.proto',
  package='profi_optim_lite',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16profi_optim_lite.proto\x12\x10profi_optim_lite\"\xb6\x0c\n\x06RecReg\x12\x0f\n\x03mID\x18\x01 \x03(\rB\x02\x10\x01\x12\x31\n\x07general\x18\x02 \x01(\n2 .profi_optim_lite.RecReg.General\x12-\n\x05photo\x18\x04 \x01(\n2\x1e.profi_optim_lite.RecReg.Photo\x12)\n\x03nav\x18\x05 \x01(\n2\x1c.profi_optim_lite.RecReg.NAV\x12-\n\x05unidt\x18\x06 \x01(\n2\x1e.profi_optim_lite.RecReg.UniDt\x12-\n\x05\x63\x61ndt\x18\x07 \x01(\n2\x1e.profi_optim_lite.RecReg.CanDt\x12-\n\x05llsdt\x18\x08 \x01(\n2\x1e.profi_optim_lite.RecReg.LLSDt\x12)\n\x03log\x18\x10 \x01(\n2\x1c.profi_optim_lite.RecReg.LOG\x1a\xdc\x01\n\x07General\x12\x0c\n\x04Time\x18\x01 \x01(\r\x12\r\n\x05IDFAS\x18\x02 \x01(\r\x12\r\n\x05IDDrv\x18\x03 \x01(\x0c\x12\x0b\n\x03\x46LG\x18\x04 \x01(\r\x12\x0f\n\x07Mileage\x18\x05 \x01(\r\x12\x0c\n\x04VImp\x18\x06 \x01(\r\x12\x0c\n\x04TImp\x18\x07 \x01(\r\x12\x0e\n\x06Uboard\x18\x08 \x01(\r\x12\x0f\n\x07\x42\x61tLife\x18\t \x01(\r\x12\x0e\n\x06SumAcc\x18\n \x01(\x11\x12\r\n\x05Phone\x18\x0b \x01(\x0c\x12\r\n\x05\x41mtrX\x18\x0c \x01(\x11\x12\r\n\x05\x41mtrY\x18\r \x01(\x11\x12\r\n\x05\x41mtrZ\x18\x0e \x01(\x11\x1a\x62\n\x05Photo\x12\x0e\n\x06POSBLK\x18\x01 \x01(\r\x12\x0f\n\x07SZPHOTO\x18\x02 \x01(\r\x12\x0c\n\x04SIZE\x18\x03 \x01(\r\x12\x0b\n\x03\x42UF\x18\x04 \x01(\x0c\x12\x0c\n\x04IDPH\x18\x05 \x01(\r\x12\x0f\n\x07IMGSTAT\x18\x06 \x01(\r\x1a`\n\x03NAV\x12\x0b\n\x03LAT\x18\x01 \x02(\x11\x12\x0b\n\x03LON\x18\x02 \x02(\x11\x12\x0e\n\x06GPSVel\x18\x03 \x02(\r\x12\x0e\n\x06GPSDir\x18\x04 \x02(\r\x12\x0f\n\x07GPSNSat\x18\x05 \x02(\r\x12\x0e\n\x06GPSAlt\x18\x06 \x02(\x11\x1aK\n\x05UniDt\x12\x0f\n\x07UniVal0\x18\x01 \x01(\x11\x12\x0f\n\x07UniVal1\x18\x02 \x01(\x11\x12\x0f\n\x07UniVal2\x18\x03 \x01(\x11\x12\x0f\n\x07UniVal3\x18\x04 \x01(\x11\x1a\xb5\x03\n\x05\x43\x61nDt\x12\r\n\x05SPN70\x18\x46 \x01(\r\x12\r\n\x05SPN91\x18[ \x01(\r\x12\x0e\n\x06SPN100\x18\x64 \x01(\r\x12\x0e\n\x06SPN110\x18n \x01(\r\x12\x0f\n\x06SPN174\x18\xae\x01 \x01(\r\x12\x0f\n\x06SPN175\x18\xaf\x01 \x01(\r\x12\x0f\n\x06SPN182\x18\xb6\x01 \x01(\r\x12\x0f\n\x06SPN184\x18\xb8\x01 \x01(\r\x12\x0f\n\x06SPN190\x18\xbe\x01 \x01(\r\x12\x0f\n\x06SPN244\x18\xf4\x01 \x01(\r\x12\x0f\n\x06SPN245\x18\xf5\x01 \x01(\r\x12\x0f\n\x06SPN247\x18\xf7\x01 \x01(\r\x12\x0f\n\x06SPN250\x18\xfa\x01 \x01(\r\x12\x0f\n\x06SPN521\x18\x89\x04 \x01(\r\x12\x0f\n\x06SPN522\x18\x8a\x04 \x01(\r\x12\x0f\n\x06SPN527\x18\x8f\x04 \x01(\r\x12\x13\n\x06SPN582\x18\xc6\x04 \x03(\rB\x02\x10\x01\x12\x0f\n\x06SPN597\x18\xd5\x04 \x01(\r\x12\x0f\n\x06SPN598\x18\xd6\x04 \x01(\r\x12\x0f\n\x06SPN914\x18\x92\x07 \x01(\r\x12\x0f\n\x06SPN916\x18\x94\x07 \x01(\r\x12\x13\n\x06SPN928\x18\xa0\x07 \x03(\rB\x02\x10\x01\x12\x10\n\x07SPN1624\x18\xd8\x0c \x01(\r\x12\x10\n\x07SPN1821\x18\x9d\x0e \x01(\r\x12\x10\n\x07SPN1856\x18\xc0\x0e \x01(\r\x1a\x95\x02\n\x05LLSDt\x12\r\n\x05TLLS1\x18\x01 \x01(\x11\x12\r\n\x05\x43LLS1\x18\x02 \x01(\r\x12\r\n\x05\x46LLS1\x18\x03 \x01(\x11\x12\r\n\x05TLLS2\x18\x04 \x01(\x11\x12\r\n\x05\x43LLS2\x18\x05 \x01(\r\x12\r\n\x05\x46LLS2\x18\x06 \x01(\x11\x12\r\n\x05TLLS3\x18\x07 \x01(\x11\x12\r\n\x05\x43LLS3\x18\x08 \x01(\r\x12\r\n\x05\x46LLS3\x18\t \x01(\x11\x12\r\n\x05TLLS4\x18\n \x01(\x11\x12\r\n\x05\x43LLS4\x18\x0b \x01(\r\x12\r\n\x05\x46LLS4\x18\x0c \x01(\x11\x12\r\n\x05TLLS5\x18\r \x01(\x11\x12\r\n\x05\x43LLS5\x18\x0e \x01(\r\x12\r\n\x05\x46LLS5\x18\x0f \x01(\x11\x12\r\n\x05TLLS6\x18\x10 \x01(\x11\x12\r\n\x05\x43LLS6\x18\x11 \x01(\r\x12\r\n\x05\x46LLS6\x18\x12 \x01(\x11\x1a\x14\n\x03LOG\x12\r\n\x05\x44\x65\x62ug\x18\x01 \x03(\t'
)




_RECREG_GENERAL = _descriptor.Descriptor(
  name='General',
  full_name='profi_optim_lite.RecReg.General',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Time', full_name='profi_optim_lite.RecReg.General.Time', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IDFAS', full_name='profi_optim_lite.RecReg.General.IDFAS', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IDDrv', full_name='profi_optim_lite.RecReg.General.IDDrv', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FLG', full_name='profi_optim_lite.RecReg.General.FLG', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Mileage', full_name='profi_optim_lite.RecReg.General.Mileage', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='VImp', full_name='profi_optim_lite.RecReg.General.VImp', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TImp', full_name='profi_optim_lite.RecReg.General.TImp', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Uboard', full_name='profi_optim_lite.RecReg.General.Uboard', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='BatLife', full_name='profi_optim_lite.RecReg.General.BatLife', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SumAcc', full_name='profi_optim_lite.RecReg.General.SumAcc', index=9,
      number=10, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Phone', full_name='profi_optim_lite.RecReg.General.Phone', index=10,
      number=11, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='AmtrX', full_name='profi_optim_lite.RecReg.General.AmtrX', index=11,
      number=12, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='AmtrY', full_name='profi_optim_lite.RecReg.General.AmtrY', index=12,
      number=13, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='AmtrZ', full_name='profi_optim_lite.RecReg.General.AmtrZ', index=13,
      number=14, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=618,
)

_RECREG_PHOTO = _descriptor.Descriptor(
  name='Photo',
  full_name='profi_optim_lite.RecReg.Photo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='POSBLK', full_name='profi_optim_lite.RecReg.Photo.POSBLK', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SZPHOTO', full_name='profi_optim_lite.RecReg.Photo.SZPHOTO', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SIZE', full_name='profi_optim_lite.RecReg.Photo.SIZE', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='BUF', full_name='profi_optim_lite.RecReg.Photo.BUF', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IDPH', full_name='profi_optim_lite.RecReg.Photo.IDPH', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IMGSTAT', full_name='profi_optim_lite.RecReg.Photo.IMGSTAT', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=620,
  serialized_end=718,
)

_RECREG_NAV = _descriptor.Descriptor(
  name='NAV',
  full_name='profi_optim_lite.RecReg.NAV',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='LAT', full_name='profi_optim_lite.RecReg.NAV.LAT', index=0,
      number=1, type=17, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='LON', full_name='profi_optim_lite.RecReg.NAV.LON', index=1,
      number=2, type=17, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='GPSVel', full_name='profi_optim_lite.RecReg.NAV.GPSVel', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='GPSDir', full_name='profi_optim_lite.RecReg.NAV.GPSDir', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='GPSNSat', full_name='profi_optim_lite.RecReg.NAV.GPSNSat', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='GPSAlt', full_name='profi_optim_lite.RecReg.NAV.GPSAlt', index=5,
      number=6, type=17, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=720,
  serialized_end=816,
)

_RECREG_UNIDT = _descriptor.Descriptor(
  name='UniDt',
  full_name='profi_optim_lite.RecReg.UniDt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='UniVal0', full_name='profi_optim_lite.RecReg.UniDt.UniVal0', index=0,
      number=1, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='UniVal1', full_name='profi_optim_lite.RecReg.UniDt.UniVal1', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='UniVal2', full_name='profi_optim_lite.RecReg.UniDt.UniVal2', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='UniVal3', full_name='profi_optim_lite.RecReg.UniDt.UniVal3', index=3,
      number=4, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=818,
  serialized_end=893,
)

_RECREG_CANDT = _descriptor.Descriptor(
  name='CanDt',
  full_name='profi_optim_lite.RecReg.CanDt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='SPN70', full_name='profi_optim_lite.RecReg.CanDt.SPN70', index=0,
      number=70, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN91', full_name='profi_optim_lite.RecReg.CanDt.SPN91', index=1,
      number=91, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN100', full_name='profi_optim_lite.RecReg.CanDt.SPN100', index=2,
      number=100, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN110', full_name='profi_optim_lite.RecReg.CanDt.SPN110', index=3,
      number=110, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN174', full_name='profi_optim_lite.RecReg.CanDt.SPN174', index=4,
      number=174, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN175', full_name='profi_optim_lite.RecReg.CanDt.SPN175', index=5,
      number=175, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN182', full_name='profi_optim_lite.RecReg.CanDt.SPN182', index=6,
      number=182, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN184', full_name='profi_optim_lite.RecReg.CanDt.SPN184', index=7,
      number=184, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN190', full_name='profi_optim_lite.RecReg.CanDt.SPN190', index=8,
      number=190, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN244', full_name='profi_optim_lite.RecReg.CanDt.SPN244', index=9,
      number=244, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN245', full_name='profi_optim_lite.RecReg.CanDt.SPN245', index=10,
      number=245, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN247', full_name='profi_optim_lite.RecReg.CanDt.SPN247', index=11,
      number=247, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN250', full_name='profi_optim_lite.RecReg.CanDt.SPN250', index=12,
      number=250, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN521', full_name='profi_optim_lite.RecReg.CanDt.SPN521', index=13,
      number=521, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN522', full_name='profi_optim_lite.RecReg.CanDt.SPN522', index=14,
      number=522, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN527', full_name='profi_optim_lite.RecReg.CanDt.SPN527', index=15,
      number=527, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN582', full_name='profi_optim_lite.RecReg.CanDt.SPN582', index=16,
      number=582, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN597', full_name='profi_optim_lite.RecReg.CanDt.SPN597', index=17,
      number=597, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN598', full_name='profi_optim_lite.RecReg.CanDt.SPN598', index=18,
      number=598, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN914', full_name='profi_optim_lite.RecReg.CanDt.SPN914', index=19,
      number=914, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN916', full_name='profi_optim_lite.RecReg.CanDt.SPN916', index=20,
      number=916, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN928', full_name='profi_optim_lite.RecReg.CanDt.SPN928', index=21,
      number=928, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN1624', full_name='profi_optim_lite.RecReg.CanDt.SPN1624', index=22,
      number=1624, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN1821', full_name='profi_optim_lite.RecReg.CanDt.SPN1821', index=23,
      number=1821, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SPN1856', full_name='profi_optim_lite.RecReg.CanDt.SPN1856', index=24,
      number=1856, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=896,
  serialized_end=1333,
)

_RECREG_LLSDT = _descriptor.Descriptor(
  name='LLSDt',
  full_name='profi_optim_lite.RecReg.LLSDt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='TLLS1', full_name='profi_optim_lite.RecReg.LLSDt.TLLS1', index=0,
      number=1, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CLLS1', full_name='profi_optim_lite.RecReg.LLSDt.CLLS1', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FLLS1', full_name='profi_optim_lite.RecReg.LLSDt.FLLS1', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TLLS2', full_name='profi_optim_lite.RecReg.LLSDt.TLLS2', index=3,
      number=4, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CLLS2', full_name='profi_optim_lite.RecReg.LLSDt.CLLS2', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FLLS2', full_name='profi_optim_lite.RecReg.LLSDt.FLLS2', index=5,
      number=6, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TLLS3', full_name='profi_optim_lite.RecReg.LLSDt.TLLS3', index=6,
      number=7, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CLLS3', full_name='profi_optim_lite.RecReg.LLSDt.CLLS3', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FLLS3', full_name='profi_optim_lite.RecReg.LLSDt.FLLS3', index=8,
      number=9, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TLLS4', full_name='profi_optim_lite.RecReg.LLSDt.TLLS4', index=9,
      number=10, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CLLS4', full_name='profi_optim_lite.RecReg.LLSDt.CLLS4', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FLLS4', full_name='profi_optim_lite.RecReg.LLSDt.FLLS4', index=11,
      number=12, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TLLS5', full_name='profi_optim_lite.RecReg.LLSDt.TLLS5', index=12,
      number=13, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CLLS5', full_name='profi_optim_lite.RecReg.LLSDt.CLLS5', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FLLS5', full_name='profi_optim_lite.RecReg.LLSDt.FLLS5', index=14,
      number=15, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TLLS6', full_name='profi_optim_lite.RecReg.LLSDt.TLLS6', index=15,
      number=16, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CLLS6', full_name='profi_optim_lite.RecReg.LLSDt.CLLS6', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='FLLS6', full_name='profi_optim_lite.RecReg.LLSDt.FLLS6', index=17,
      number=18, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1336,
  serialized_end=1613,
)

_RECREG_LOG = _descriptor.Descriptor(
  name='LOG',
  full_name='profi_optim_lite.RecReg.LOG',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Debug', full_name='profi_optim_lite.RecReg.LOG.Debug', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1615,
  serialized_end=1635,
)

_RECREG = _descriptor.Descriptor(
  name='RecReg',
  full_name='profi_optim_lite.RecReg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mID', full_name='profi_optim_lite.RecReg.mID', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='general', full_name='profi_optim_lite.RecReg.general', index=1,
      number=2, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='photo', full_name='profi_optim_lite.RecReg.photo', index=2,
      number=4, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nav', full_name='profi_optim_lite.RecReg.nav', index=3,
      number=5, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unidt', full_name='profi_optim_lite.RecReg.unidt', index=4,
      number=6, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='candt', full_name='profi_optim_lite.RecReg.candt', index=5,
      number=7, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='llsdt', full_name='profi_optim_lite.RecReg.llsdt', index=6,
      number=8, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log', full_name='profi_optim_lite.RecReg.log', index=7,
      number=16, type=10, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RECREG_GENERAL, _RECREG_PHOTO, _RECREG_NAV, _RECREG_UNIDT, _RECREG_CANDT, _RECREG_LLSDT, _RECREG_LOG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=1635,
)

_RECREG_GENERAL.containing_type = _RECREG
_RECREG_PHOTO.containing_type = _RECREG
_RECREG_NAV.containing_type = _RECREG
_RECREG_UNIDT.containing_type = _RECREG
_RECREG_CANDT.containing_type = _RECREG
_RECREG_LLSDT.containing_type = _RECREG
_RECREG_LOG.containing_type = _RECREG
_RECREG.fields_by_name['general'].message_type = _RECREG_GENERAL
_RECREG.fields_by_name['photo'].message_type = _RECREG_PHOTO
_RECREG.fields_by_name['nav'].message_type = _RECREG_NAV
_RECREG.fields_by_name['unidt'].message_type = _RECREG_UNIDT
_RECREG.fields_by_name['candt'].message_type = _RECREG_CANDT
_RECREG.fields_by_name['llsdt'].message_type = _RECREG_LLSDT
_RECREG.fields_by_name['log'].message_type = _RECREG_LOG
DESCRIPTOR.message_types_by_name['RecReg'] = _RECREG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RecReg = _reflection.GeneratedProtocolMessageType('RecReg', (_message.Message,), {

  'General' : _reflection.GeneratedProtocolMessageType('General', (_message.Message,), {
    'DESCRIPTOR' : _RECREG_GENERAL,
    '__module__' : 'profi_optim_lite_pb2'
    # @@protoc_insertion_point(class_scope:profi_optim_lite.RecReg.General)
    })
  ,

  'Photo' : _reflection.GeneratedProtocolMessageType('Photo', (_message.Message,), {
    'DESCRIPTOR' : _RECREG_PHOTO,
    '__module__' : 'profi_optim_lite_pb2'
    # @@protoc_insertion_point(class_scope:profi_optim_lite.RecReg.Photo)
    })
  ,

  'NAV' : _reflection.GeneratedProtocolMessageType('NAV', (_message.Message,), {
    'DESCRIPTOR' : _RECREG_NAV,
    '__module__' : 'profi_optim_lite_pb2'
    # @@protoc_insertion_point(class_scope:profi_optim_lite.RecReg.NAV)
    })
  ,

  'UniDt' : _reflection.GeneratedProtocolMessageType('UniDt', (_message.Message,), {
    'DESCRIPTOR' : _RECREG_UNIDT,
    '__module__' : 'profi_optim_lite_pb2'
    # @@protoc_insertion_point(class_scope:profi_optim_lite.RecReg.UniDt)
    })
  ,

  'CanDt' : _reflection.GeneratedProtocolMessageType('CanDt', (_message.Message,), {
    'DESCRIPTOR' : _RECREG_CANDT,
    '__module__' : 'profi_optim_lite_pb2'
    # @@protoc_insertion_point(class_scope:profi_optim_lite.RecReg.CanDt)
    })
  ,

  'LLSDt' : _reflection.GeneratedProtocolMessageType('LLSDt', (_message.Message,), {
    'DESCRIPTOR' : _RECREG_LLSDT,
    '__module__' : 'profi_optim_lite_pb2'
    # @@protoc_insertion_point(class_scope:profi_optim_lite.RecReg.LLSDt)
    })
  ,

  'LOG' : _reflection.GeneratedProtocolMessageType('LOG', (_message.Message,), {
    'DESCRIPTOR' : _RECREG_LOG,
    '__module__' : 'profi_optim_lite_pb2'
    # @@protoc_insertion_point(class_scope:profi_optim_lite.RecReg.LOG)
    })
  ,
  'DESCRIPTOR' : _RECREG,
  '__module__' : 'profi_optim_lite_pb2'
  # @@protoc_insertion_point(class_scope:profi_optim_lite.RecReg)
  })
_sym_db.RegisterMessage(RecReg)
_sym_db.RegisterMessage(RecReg.General)
_sym_db.RegisterMessage(RecReg.Photo)
_sym_db.RegisterMessage(RecReg.NAV)
_sym_db.RegisterMessage(RecReg.UniDt)
_sym_db.RegisterMessage(RecReg.CanDt)
_sym_db.RegisterMessage(RecReg.LLSDt)
_sym_db.RegisterMessage(RecReg.LOG)


_RECREG_CANDT.fields_by_name['SPN582']._options = None
_RECREG_CANDT.fields_by_name['SPN928']._options = None
_RECREG.fields_by_name['mID']._options = None
# @@protoc_insertion_point(module_scope)
